package com.xinelu.manage.mapper.batchsendtaskinfo;

import com.xinelu.manage.domain.batchsendtaskinfo.BatchSendTaskInfo;
import com.xinelu.manage.dto.batchsendtaskinfo.BatchSendTaskDto;

import java.util.List;

/**
 * 批量推送任务信息Mapper接口
 *
 * @author zh
 * @date 2026-04-26
 */
public interface BatchSendTaskInfoMapper {
    /**
     * 查询批量推送任务信息
     *
     * @param id 批量推送任务信息主键
     * @return 批量推送任务信息
     */
    BatchSendTaskInfo selectBatchSendTaskInfoById(Long id);

    /**
     * 查询批量推送任务信息列表
     *
     * @param batchSendTaskInfo 批量推送任务信息
     * @return 批量推送任务信息集合
     */
    List<BatchSendTaskInfo> selectBatchSendTaskInfoList(BatchSendTaskDto batchSendTaskInfo);

    /**
     * 新增批量推送任务信息
     *
     * @param batchSendTaskInfo 批量推送任务信息
     * @return 结果
     */
    int insertBatchSendTaskInfo(BatchSendTaskInfo batchSendTaskInfo);

    /**
     * 修改批量推送任务信息
     *
     * @param batchSendTaskInfo 批量推送任务信息
     * @return 结果
     */
    int updateBatchSendTaskInfo(BatchSendTaskInfo batchSendTaskInfo);

    /**
     * 删除批量推送任务信息
     *
     * @param id 批量推送任务信息主键
     * @return 结果
     */
    int deleteBatchSendTaskInfoById(Long id);

    /**
     * 批量删除批量推送任务信息
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    int deleteBatchSendTaskInfoByIds(Long[] ids);

    /**
     * 新增患者信息
     *
     * @param batchSendTaskInfoList 批量任务信息
     * @return 结果
     */
    int insertBatchSendTaskInfoList(List<BatchSendTaskInfo> batchSendTaskInfoList);
}